import { AnimationEvent } from '@angular/animations';
import { ElementRef, EventEmitter, OnDestroy, TemplateRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { OverlayService } from 'primeng/api';
import { BaseComponent } from 'primeng/basecomponent';
import { ConnectedOverlayScrollHandler } from 'primeng/dom';
import { Nullable, VoidListener } from 'primeng/ts-helpers';
import { ColorPickerChangeEvent } from './colorpicker.interface';
import { ColorPickerStyle } from './style/colorpickerstyle';
import * as i0 from "@angular/core";
import * as i1 from "primeng/api";
export declare const COLORPICKER_VALUE_ACCESSOR: any;
/**
 * ColorPicker groups a collection of contents in tabs.
 * @group Components
 */
export declare class ColorPicker extends BaseComponent implements ControlValueAccessor, OnDestroy {
    overlayService: OverlayService;
    /**
     * Inline style of the component.
     * @group Props
     */
    style: {
        [klass: string]: any;
    } | null | undefined;
    /**
     * Style class of the component.
     * @group Props
     */
    styleClass: string | undefined;
    /**
     * Whether to display as an overlay or not.
     * @group Props
     */
    inline: boolean | undefined;
    /**
     * Format to use in value binding.
     * @group Props
     */
    format: 'hex' | 'rgb' | 'hsb';
    /**
     * Target element to attach the overlay, valid values are "body" or a local ng-template variable of another element (note: use binding with brackets for template variables, e.g. [appendTo]="mydiv" for a div element having #mydiv as variable name).
     * @group Props
     */
    appendTo: HTMLElement | ElementRef | TemplateRef<any> | string | null | undefined | any;
    /**
     * When present, it specifies that the component should be disabled.
     * @group Props
     */
    disabled: boolean | undefined;
    /**
     * Index of the element in tabbing order.
     * @group Props
     */
    tabindex: string | undefined;
    /**
     * Identifier of the focus input to match a label defined for the dropdown.
     * @group Props
     */
    inputId: string | undefined;
    /**
     * Whether to automatically manage layering.
     * @group Props
     */
    autoZIndex: boolean;
    /**
     * Base zIndex value to use in layering.
     * @group Props
     */
    baseZIndex: number;
    /**
     * Transition options of the show animation.
     * @group Props
     */
    showTransitionOptions: string;
    /**
     * Transition options of the hide animation.
     * @group Props
     */
    hideTransitionOptions: string;
    /**
     * When present, it specifies that the component should automatically get focus on load.
     * @group Props
     */
    autofocus: boolean | undefined;
    /**
     * Callback to invoke on value change.
     * @param {ColorPickerChangeEvent} event - Custom value change event.
     * @group Emits
     */
    onChange: EventEmitter<ColorPickerChangeEvent>;
    /**
     * Callback to invoke on panel is shown.
     * @group Emits
     */
    onShow: EventEmitter<any>;
    /**
     * Callback to invoke on panel is hidden.
     * @group Emits
     */
    onHide: EventEmitter<any>;
    containerViewChild: Nullable<ElementRef>;
    inputViewChild: Nullable<ElementRef>;
    value: any;
    inputBgColor: string | undefined;
    shown: Nullable<boolean>;
    overlayVisible: Nullable<boolean>;
    defaultColor: string;
    onModelChange: Function;
    onModelTouched: Function;
    documentClickListener: VoidListener;
    documentResizeListener: VoidListener;
    documentMousemoveListener: VoidListener;
    documentMouseupListener: VoidListener;
    documentHueMoveListener: VoidListener;
    scrollHandler: Nullable<ConnectedOverlayScrollHandler>;
    selfClick: Nullable<boolean>;
    colorDragging: Nullable<boolean>;
    hueDragging: Nullable<boolean>;
    overlay: Nullable<HTMLDivElement>;
    colorSelectorViewChild: Nullable<ElementRef>;
    colorHandleViewChild: Nullable<ElementRef>;
    hueViewChild: Nullable<ElementRef>;
    hueHandleViewChild: Nullable<ElementRef>;
    _componentStyle: ColorPickerStyle;
    constructor(overlayService: OverlayService);
    set colorSelector(element: ElementRef);
    set colorHandle(element: ElementRef);
    set hue(element: ElementRef);
    set hueHandle(element: ElementRef);
    get ariaLabel(): any;
    onHueMousedown(event: MouseEvent): void;
    onHueDragStart(event: TouchEvent): void;
    onColorDragStart(event: TouchEvent): void;
    pickHue(event: MouseEvent | TouchEvent, position?: any): void;
    onColorMousedown(event: MouseEvent): void;
    onDrag(event: TouchEvent): void;
    onDragEnd(): void;
    pickColor(event: MouseEvent | TouchEvent, position?: any): void;
    getValueToUpdate(): any;
    updateModel(): void;
    writeValue(value: any): void;
    updateColorSelector(): void;
    updateUI(): void;
    onInputFocus(): void;
    show(): void;
    onOverlayAnimationStart(event: AnimationEvent): void;
    onOverlayAnimationEnd(event: AnimationEvent): void;
    appendOverlay(): void;
    restoreOverlayAppend(): void;
    alignOverlay(): void;
    hide(): void;
    onInputClick(): void;
    togglePanel(): void;
    onInputKeydown(event: KeyboardEvent): void;
    onOverlayClick(event: MouseEvent): void;
    registerOnChange(fn: Function): void;
    registerOnTouched(fn: Function): void;
    setDisabledState(val: boolean): void;
    bindDocumentClickListener(): void;
    unbindDocumentClickListener(): void;
    bindDocumentMousemoveListener(): void;
    unbindDocumentMousemoveListener(): void;
    bindDocumentMouseupListener(): void;
    unbindDocumentMouseupListener(): void;
    bindDocumentResizeListener(): void;
    unbindDocumentResizeListener(): void;
    onWindowResize(): void;
    bindScrollListener(): void;
    unbindScrollListener(): void;
    validateHSB(hsb: {
        h: number;
        s: number;
        b: number;
    }): {
        h: number;
        s: number;
        b: number;
    };
    validateRGB(rgb: {
        r: number;
        g: number;
        b: number;
    }): {
        r: number;
        g: number;
        b: number;
    };
    validateHEX(hex: string): string;
    HEXtoRGB(hex: string): {
        r: number;
        g: number;
        b: number;
    };
    HEXtoHSB(hex: string): {
        h: number;
        s: number;
        b: number;
    };
    RGBtoHSB(rgb: {
        r: number;
        g: number;
        b: number;
    }): {
        h: number;
        s: number;
        b: number;
    };
    HSBtoRGB(hsb: {
        h: number;
        s: number;
        b: number;
    }): {
        r: number;
        g: number;
        b: number;
    };
    RGBtoHEX(rgb: {
        r: number;
        g: number;
        b: number;
    }): string;
    HSBtoHEX(hsb: {
        h: number;
        s: number;
        b: number;
    }): string;
    onOverlayHide(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColorPicker, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColorPicker, "p-colorPicker, p-colorpicker, p-color-picker", never, { "style": { "alias": "style"; "required": false; }; "styleClass": { "alias": "styleClass"; "required": false; }; "inline": { "alias": "inline"; "required": false; }; "format": { "alias": "format"; "required": false; }; "appendTo": { "alias": "appendTo"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "inputId": { "alias": "inputId"; "required": false; }; "autoZIndex": { "alias": "autoZIndex"; "required": false; }; "baseZIndex": { "alias": "baseZIndex"; "required": false; }; "showTransitionOptions": { "alias": "showTransitionOptions"; "required": false; }; "hideTransitionOptions": { "alias": "hideTransitionOptions"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; }, { "onChange": "onChange"; "onShow": "onShow"; "onHide": "onHide"; }, never, never, true, never>;
    static ngAcceptInputType_inline: unknown;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_autoZIndex: unknown;
    static ngAcceptInputType_baseZIndex: unknown;
    static ngAcceptInputType_autofocus: unknown;
}
export declare class ColorPickerModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<ColorPickerModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<ColorPickerModule, never, [typeof ColorPicker, typeof i1.SharedModule], [typeof ColorPicker, typeof i1.SharedModule]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<ColorPickerModule>;
}
