import { AfterContentInit, AfterViewInit, ElementRef, EventEmitter, OnDestroy, QueryList, TemplateRef } from '@angular/core';
import { PrimeTemplate } from 'primeng/api';
import { BaseComponent } from 'primeng/basecomponent';
import { ButtonProps } from 'primeng/button';
import { Nullable, VoidListener } from 'primeng/ts-helpers';
import { DrawerStyle } from './style/drawerstyle';
import * as i0 from "@angular/core";
import * as i1 from "primeng/api";
/**
 * Sidebar is a panel component displayed as an overlay at the edges of the screen.
 * @group Components
 */
export declare class Drawer extends BaseComponent implements AfterViewInit, AfterContentInit, OnDestroy {
    /**
     *  Target element to attach the dialog, valid values are "body" or a local ng-template variable of another element (note: use binding with brackets for template variables, e.g. [appendTo]="mydiv" for a div element having #mydiv as variable name).
     * @group Props
     */
    appendTo: HTMLElement | ElementRef | TemplateRef<any> | string | null | undefined | any;
    /**
     * Whether to block scrolling of the document when drawer is active.
     * @group Props
     */
    blockScroll: boolean;
    /**
     * Inline style of the component.
     * @group Props
     */
    style: {
        [klass: string]: any;
    } | null | undefined;
    /**
     * Style class of the component.
     * @group Props
     */
    styleClass: string | undefined;
    /**
     * Aria label of the close icon.
     * @group Props
     */
    ariaCloseLabel: string | undefined;
    /**
     * Whether to automatically manage layering.
     * @group Props
     */
    autoZIndex: boolean;
    /**
     * Base zIndex value to use in layering.
     * @group Props
     */
    baseZIndex: number;
    /**
     * Whether an overlay mask is displayed behind the drawer.
     * @group Props
     */
    modal: boolean;
    /**
     * Used to pass all properties of the ButtonProps to the Button component.
     * @group Props
     */
    closeButtonProps: ButtonProps;
    /**
     * Whether to dismiss drawer on click of the mask.
     * @group Props
     */
    dismissible: boolean;
    /**
     * Whether to display the close icon.
     * @group Props
     * @deprecated use 'closable' instead.
     */
    showCloseIcon: boolean;
    /**
     * Specifies if pressing escape key should hide the drawer.
     * @group Props
     */
    closeOnEscape: boolean;
    /**
     * Transition options of the animation.
     * @group Props
     */
    transitionOptions: string;
    /**
     * Specifies the visibility of the dialog.
     * @group Props
     */
    get visible(): boolean;
    set visible(val: boolean);
    /**
     * Specifies the position of the drawer, valid values are "left", "right", "bottom" and "top".
     * @group Props
     */
    get position(): string;
    set position(value: string);
    /**
     * Adds a close icon to the header to hide the dialog.
     * @group Props
     */
    get fullScreen(): boolean;
    set fullScreen(value: boolean);
    /**
     * Title content of the dialog.
     * @group Props
     */
    header: string | undefined;
    /**
     * Style of the mask.
     * @group Props
     */
    maskStyle: {
        [klass: string]: any;
    } | null | undefined;
    /**
     * Whether to display close button.
     * @group Props
     * @defaultValue true
     */
    closable: boolean;
    /**
     * Callback to invoke when dialog is shown.
     * @group Emits
     */
    onShow: EventEmitter<any>;
    /**
     * Callback to invoke when dialog is hidden.
     * @group Emits
     */
    onHide: EventEmitter<any>;
    /**
     * Callback to invoke when dialog visibility is changed.
     * @param {boolean} value - Visible value.
     * @group Emits
     */
    visibleChange: EventEmitter<boolean>;
    maskRef: ElementRef | undefined;
    containerViewChild: ElementRef | undefined;
    closeButtonViewChild: ElementRef | undefined;
    initialized: boolean | undefined;
    _visible: boolean | undefined;
    _position: string;
    _fullScreen: boolean;
    container: Nullable<HTMLDivElement>;
    transformOptions: any;
    mask: Nullable<HTMLDivElement>;
    maskClickListener: VoidListener;
    documentEscapeListener: VoidListener;
    animationEndListener: VoidListener;
    _componentStyle: DrawerStyle;
    ngAfterViewInit(): void;
    /**
     * Content template for the content of the drawer.
     * @group Templates
     */
    headerTemplate: TemplateRef<any> | undefined;
    /**
     * Header template for the header of the drawer.
     * @group Templates
     */
    footerTemplate: TemplateRef<any> | undefined;
    /**
     * Content template for the footer of the drawer.
     * @group Templates
     */
    contentTemplate: TemplateRef<any> | undefined;
    /**
     * Close icon template for the close icon of the drawer.
     * @group Templates
     */
    closeIconTemplate: TemplateRef<any> | undefined;
    /**
     * Headless template for the headless drawer.
     * @group Templates
     */
    headlessTemplate: TemplateRef<any> | undefined;
    _headerTemplate: TemplateRef<any> | undefined;
    _footerTemplate: TemplateRef<any> | undefined;
    _contentTemplate: TemplateRef<any> | undefined;
    _closeIconTemplate: TemplateRef<any> | undefined;
    _headlessTemplate: TemplateRef<any> | undefined;
    templates: QueryList<PrimeTemplate> | undefined;
    ngAfterContentInit(): void;
    onKeyDown(event: KeyboardEvent): void;
    show(): void;
    hide(emit?: boolean): void;
    close(event: Event): void;
    enableModality(): void;
    disableModality(): void;
    destroyModal(): void;
    onAnimationStart(event: any): void;
    onAnimationEnd(event: any): void;
    appendContainer(): void;
    bindDocumentEscapeListener(): void;
    unbindDocumentEscapeListener(): void;
    unbindMaskClickListener(): void;
    unbindGlobalListeners(): void;
    unbindAnimationEndListener(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<Drawer, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<Drawer, "p-drawer", never, { "appendTo": { "alias": "appendTo"; "required": false; }; "blockScroll": { "alias": "blockScroll"; "required": false; }; "style": { "alias": "style"; "required": false; }; "styleClass": { "alias": "styleClass"; "required": false; }; "ariaCloseLabel": { "alias": "ariaCloseLabel"; "required": false; }; "autoZIndex": { "alias": "autoZIndex"; "required": false; }; "baseZIndex": { "alias": "baseZIndex"; "required": false; }; "modal": { "alias": "modal"; "required": false; }; "closeButtonProps": { "alias": "closeButtonProps"; "required": false; }; "dismissible": { "alias": "dismissible"; "required": false; }; "showCloseIcon": { "alias": "showCloseIcon"; "required": false; }; "closeOnEscape": { "alias": "closeOnEscape"; "required": false; }; "transitionOptions": { "alias": "transitionOptions"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "position": { "alias": "position"; "required": false; }; "fullScreen": { "alias": "fullScreen"; "required": false; }; "header": { "alias": "header"; "required": false; }; "maskStyle": { "alias": "maskStyle"; "required": false; }; "closable": { "alias": "closable"; "required": false; }; }, { "onShow": "onShow"; "onHide": "onHide"; "visibleChange": "visibleChange"; }, ["headerTemplate", "footerTemplate", "contentTemplate", "closeIconTemplate", "headlessTemplate", "templates"], ["*"], true, never>;
    static ngAcceptInputType_blockScroll: unknown;
    static ngAcceptInputType_autoZIndex: unknown;
    static ngAcceptInputType_baseZIndex: unknown;
    static ngAcceptInputType_modal: unknown;
    static ngAcceptInputType_dismissible: unknown;
    static ngAcceptInputType_showCloseIcon: unknown;
    static ngAcceptInputType_closeOnEscape: unknown;
    static ngAcceptInputType_closable: unknown;
}
export declare class DrawerModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<DrawerModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<DrawerModule, never, [typeof Drawer, typeof i1.SharedModule], [typeof Drawer, typeof i1.SharedModule]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<DrawerModule>;
}
