import { ElementRef, EventEmitter } from '@angular/core';
import { BaseComponent } from 'primeng/basecomponent';
import { InputSwitchChangeEvent } from './inputswitch.interface';
import { InputSwitchStyle } from './style/inputswitchstyle';
import * as i0 from "@angular/core";
import * as i1 from "primeng/api";
export declare const INPUTSWITCH_VALUE_ACCESSOR: any;
/**
 * InputSwitch is used to select a boolean value.
 * @group Components
 */
export declare class InputSwitch extends BaseComponent {
    /**
     * Inline style of the component.
     * @group Props
     */
    style: {
        [klass: string]: any;
    } | null | undefined;
    /**
     * Style class of the component.
     * @group Props
     */
    styleClass: string | undefined;
    /**
     * Index of the element in tabbing order.
     * @group Props
     */
    tabindex: number | undefined;
    /**
     * Identifier of the input element.
     * @group Props
     */
    inputId: string | undefined;
    /**
     * Name of the input element.
     * @group Props
     */
    name: string | undefined;
    /**
     * When present, it specifies that the element should be disabled.
     * @group Props
     */
    disabled: boolean | undefined;
    /**
     * When present, it specifies that the component cannot be edited.
     * @group Props
     */
    readonly: boolean | undefined;
    /**
     * Value in checked state.
     * @group Props
     */
    trueValue: any;
    /**
     * Value in unchecked state.
     * @group Props
     */
    falseValue: any;
    /**
     * Used to define a string that autocomplete attribute the current element.
     * @group Props
     */
    ariaLabel: string | undefined;
    /**
     * Establishes relationships between the component and label(s) where its value should be one or more element IDs.
     * @group Props
     */
    ariaLabelledBy: string | undefined;
    /**
     * When present, it specifies that the component should automatically get focus on load.
     * @group Props
     */
    autofocus: boolean | undefined;
    /**
     * Callback to invoke when the on value change.
     * @param {InputSwitchChangeEvent} event - Custom change event.
     * @group Emits
     */
    onChange: EventEmitter<InputSwitchChangeEvent>;
    input: ElementRef;
    modelValue: any;
    focused: boolean;
    onModelChange: Function;
    onModelTouched: Function;
    _componentStyle: InputSwitchStyle;
    onClick(event: Event): void;
    onFocus(): void;
    onBlur(): void;
    writeValue(value: any): void;
    registerOnChange(fn: Function): void;
    registerOnTouched(fn: Function): void;
    setDisabledState(val: boolean): void;
    checked(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<InputSwitch, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InputSwitch, "p-inputSwitch, p-inputswitch", never, { "style": { "alias": "style"; "required": false; }; "styleClass": { "alias": "styleClass"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "inputId": { "alias": "inputId"; "required": false; }; "name": { "alias": "name"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "trueValue": { "alias": "trueValue"; "required": false; }; "falseValue": { "alias": "falseValue"; "required": false; }; "ariaLabel": { "alias": "ariaLabel"; "required": false; }; "ariaLabelledBy": { "alias": "ariaLabelledBy"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; }, { "onChange": "onChange"; }, never, never, true, never>;
    static ngAcceptInputType_tabindex: unknown;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_readonly: unknown;
    static ngAcceptInputType_autofocus: unknown;
}
export declare class InputSwitchModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<InputSwitchModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<InputSwitchModule, never, [typeof InputSwitch, typeof i1.SharedModule], [typeof InputSwitch, typeof i1.SharedModule]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<InputSwitchModule>;
}
